@@ -1,8 +1,12 @@
 from .error_handling import errorHandling
 
 from .generate_star_chart import getStarList
-from .generate_star_chart import plotStarChart
+from .generate_star_chart import plotStereographicProjection
 
 from .declination_r_axis import calculateRuler
 from .declination_r_axis import calculateRadiusOfCircle
 from .declination_r_axis import calculateLength
+
+from .ra_dec_precession_vondrak import ltp_pbmat
+from .ra_dec_precession_vondrak import pdp
+from .ra_dec_precession_vondrak import ra_dec
